@@ -11,30 +11,40 @@ class MqClientExceptionClass(Exception):
 class MqClientProcessLoopTimeoutExceptionClass(MqClientExceptionClass):
   pass
 
+class MqClientThreadHealthCheckExceptionClass(MqClientExceptionClass):
+  pass
+
 class RecieveThread(threading.Thread):
   running = None
   sleepTime = None
   stopped = None
   loopIterationFunction = None
+  thrownException = None
   def __init__(self, sleepTime, loopIterationFunction):
     self.running = True
     self.sleepTime = sleepTime
     self.stopped = False
     self.loopIterationFunction = loopIterationFunction
+    self.thrownException = None
 
     super(RecieveThread, self).__init__()
 
   def run(self):
-    self.running = True
-    print('MQ Client recieve thread starting')
-    while self.running:
-      self.loopIterationFunction()
-      time.sleep(self.sleepTime)
-    print('MQ Client recieve thread terminating')
-    self.stopped = True
-
+    try:
+      self.running = True
+      print('MQ Client recieve thread starting')
+      while self.running:
+        self.loopIterationFunction()
+        time.sleep(self.sleepTime)
+      print('MQ Client recieve thread terminating')
+      self.stopped = True
+    except Exception as Excep:
+      print("MQ CLient recieve thread throwing an Exception")
+      self.thrownException = MqClientThreadHealthCheckExceptionClass("MQ Client recieve thread threw an exception - " +  str(self.selfthrownException))
+      raise Excep
 
   def close(self, wait):
+    #Run in controller thread to stop subthread
     if self.stopped:
       raise MqClientExceptionClass("Closing thread twice")
     self.stopped = False
@@ -43,6 +53,14 @@ class RecieveThread(threading.Thread):
       while self.stopped == False:
         time.sleep(self.sleepTime)
 
+  def healthCheck(self):
+    #Run in controller thread to raise any exceptions
+    if self.running:
+      if not self.isAlive():
+        raise MqClientThreadHealthCheckExceptionClass("MQ Client thread is no longer alive")
+    if self.selfthrownException is not None:
+      raise self.selfthrownException
+
 class MqClientBaseClass():
   destinationPrefix = None
   subscriptions = None
@@ -125,6 +143,12 @@ class MqClientBaseClass():
     self.recieveThread = RecieveThread(sleepTime, loopIterationFunction=self.processLoopIteration)
     self.recieveThread.start()
 
+  def threadHealthCheck(self):
+    #Check the health of the thread and raise an exception if there is a problem
+    if self.recieveThread is None:
+      raise MqClientThreadHealthCheckExceptionClass("MQ Client thread was never started")
+    self.recieveThread.healthCheck()
+
   #********************************************************
   # Functions called from derived class only
   #********************************************************
